ITT we're boomers online - The Something Awful Forums
Description: ITT we're boomers online

Redacted

AEMINAL May 22, 2015 barf barf i am a dog, barf on your carpet, barf | #### Songbearer posted: I DO NOT UNDERSTAND I JUST WANT TO BROWSE "INTERNET" ON MY PHONE I DO NOT WANT TO USE CHROME OR HOTFOX OR EDGE OR ANYTHING!! I DONT WANT TO PAY FOR THESE I WANT TO USE ""INTERNET"!!!! I HAVE NETFLIX I DONT WANT HOTFOx Hotfox sounds cool I'm going to Download it Thank you *secretly wishes this awakens something inside of his dead soul*
# ? Dec 5, 2024 21:45 | Profile Message Post History Rap Sheet

emSparkly Nov 21, 2022 I'm open to interpretation! The interpretation includes ilovebeersooomuch | Oh no! My computer is infected and I need to call Microsoft support at the number listed below!
# ? Dec 5, 2024 21:46 | Profile Message Post History Rap Sheet

AEMINAL May 22, 2015 barf barf i am a dog, barf on your carpet, barf | #### redshirt posted: JEREMY MY COMPUTER IS NOT LOADING!!! Geek squad got 200 viruses out of mine when it did that now I go monthly and they're so fast about it always smiling and chuckling very nice white young boys
# ? Dec 5, 2024 21:50 | Profile Message Post History Rap Sheet

emSparkly Nov 21, 2022 I'm open to interpretation! The interpretation includes ilovebeersooomuch | How do I talk to my grandson? He thinks he’s a transgender and I’m afraid I won’t be getting great grandkids if he chops his nuts off.
# ? Dec 5, 2024 22:00 | Profile Message Post History Rap Sheet

nullandvoid Mar 6, 2006 And what rough beast, its hour come round at last, slouches towards Bethlehem to be born? | I;m thinking about thos Beans
# ? Dec 5, 2024 22:23 | Profile Message Post History Rap Sheet

redshirt Aug 10, 2007 | Fw:Fw:Fw:Fw:Fw:Fw: And so on such... forever!
# ? Dec 5, 2024 22:27 | Profile Message Post History Rap Sheet

signalnoise Mar 7, 2008 | my hotmail it aint loadin can u fix
# ? Dec 5, 2024 22:52 | Profile Post History Rap Sheet

Justin Godscock Oct 11, 2004 Listen here, funnyman! | I don't want to break the computer!!
# ? Dec 5, 2024 23:20 | Profile Message Post History Rap Sheet

Haptical Sales Slut Mar 14, 2010 Age 18 to 49 | Fucking Italians
# ? Dec 6, 2024 04:02 | Profile Message Post History Rap Sheet

The Hello Machine Jul 18, 2021 I'm not a real machine, but I am a real Hello-sayer. | #### AEMINAL posted: sorry Not very boomer, op
# ? Dec 6, 2024 04:18 | Profile Message Post History Rap Sheet

A Fancy Hat Nov 18, 2016 Feelin' Fine. | Heard sirens???? What is going on
# ? Dec 6, 2024 05:45 | Profile Message Post History Rap Sheet

Professor Shark May 22, 2012 | I heard the sirens too and it could be a coincidence but I saw some suspicious looking kids at the park earlier
# ? Dec 6, 2024 06:00 | Profile Message Post History Rap Sheet

Zybourne Clock Oct 25, 2011 Poke me. | PLEASE ONLY WRITE WITH CAPS LOCK ON,,, MY EYES ARE TOO BAD TO READ LOWER CASE,,, THANKS AND GOD BLESS,,,
# ? Dec 6, 2024 06:04 | Profile Message Post History Rap Sheet

A Fancy Hat Nov 18, 2016 Feelin' Fine. | your aunt cathy is in the hospital. doctors say they dont know where the bleeding is coming from and they cant perform surgery until they figure it out. your uncle is getting ready 4 her 2 die. btw do you have my copy of Stakeout any where
# ? Dec 6, 2024 07:40 | Profile Message Post History Rap Sheet

Strategic Tea Sep 1, 2012 | Hi! I'm listening to Pink Floyd's Dark Side of the Moon on Spotify! Stream for free at httpes://www....
# ? Dec 6, 2024 07:58 | Profile Post History Rap Sheet

Caesar Saladin Aug 15, 2004 | i need you to scan something for me
# ? Dec 6, 2024 07:59 | Profile Message Post History Rap Sheet

TheMostFrench Jul 12, 2009 Stop for me, it's the claw! | Hey can the y send this email for me? Please cc me into it so I have a copy. The sent messages folder? No I want it in my inbox so I can see it!
# ? Dec 6, 2024 08:31 | Profile Message Post History Rap Sheet

A Fancy Hat Nov 18, 2016 Feelin' Fine. | Another sad Christmas here as my ungrateful son refuses to bring my grandaughter by to visit. I haven't held my grandbaby in 3 years and have only spoken to her on phone once in the last year! He coddles her so badly, telling everyone she has a peanut allergy. I fed her a "handful" of peanuts and some peanut butter ice cream (she LOVED it!) and now I'm "the bad guy" for doing it. One day I will be dead and he will realize his horrible crime.
# ? Dec 6, 2024 08:48 | Profile Message Post History Rap Sheet

peanut Sep 8, 2007 | flirty comments on jigidi.com puzzles
# ? Dec 6, 2024 09:05 | Profile Message Post History Rap Sheet

Escape From Noise Jul 27, 2004 | #### peanut posted: flirty comments on jigidi.com puzzles Gettin' jigidi with it.
# ? Dec 6, 2024 09:18 | Profile Message Post History Rap Sheet

Smugworth Apr 18, 2003 | yeah this 1200sqft house is $500k go back to your shitty little apartment if you don't like it zoomer
# ? Dec 6, 2024 09:23 | Profile Message Post History Rap Sheet

big nipples big life May 12, 2014 | #### nullandvoid posted: I;m thinking about thos Beans I'm sad to report that Bill Foster, the thos beans guy, passed away
# ? Dec 6, 2024 09:27 | Profile Message Post History Rap Sheet

Escape From Noise Jul 27, 2004 | #### big nipples big life posted: I'm sad to report that Bill Foster, the thos beans guy, passed away It's bean real.
# ? Dec 6, 2024 09:31 | Profile Message Post History Rap Sheet

Bonzo Mar 11, 2004 Just like Mama used to make it! | Thank a CEO for their service
# ? Dec 6, 2024 09:41 | Profile Message Post History Rap Sheet

Shamewave Nov 25, 2024 |
# ? Dec 6, 2024 10:28 | Profile Post History Rap Sheet

Escape From Noise Jul 27, 2004 |
# ? Dec 6, 2024 10:32 | Profile Message Post History Rap Sheet

TheMostFrench Jul 12, 2009 Stop for me, it's the claw! | Those kids should be grateful I gave them a job, I don't know why the complain about being asked to stay back after closing time without pay.
# ? Dec 6, 2024 10:42 | Profile Message Post History Rap Sheet

big nipples big life May 12, 2014 | that Buscemi minion is so fucking cursed.
# ? Dec 6, 2024 10:46 | Profile Message Post History Rap Sheet

redshirt Aug 10, 2007 | Can you make the screen bigger dear?
# ? Dec 6, 2024 10:47 | Profile Message Post History Rap Sheet

A Fancy Hat Nov 18, 2016 Feelin' Fine. | did anyone just hear an explosion? I am off Manor Drive
# ? Dec 6, 2024 10:50 | Profile Message Post History Rap Sheet

flubber nuts Oct 5, 2005 | Ed Balls
# ? Dec 6, 2024 10:56 | Profile Message Post History Rap Sheet

Escape From Noise Jul 27, 2004 | [Cranks the Christmas tunes]
# ? Dec 6, 2024 10:57 | Profile Message Post History Rap Sheet

Hihohe Oct 4, 2008 Fuck you and the sun you live under | *Sees a question posted online from a random stranger* I DONT KNOW ANYTHING ABOUT THIS, I HOPE YOU FIGURE IT OUT
# ? Dec 6, 2024 11:00 | Profile Message Post History Rap Sheet

The Bramble Mar 16, 2004 | Buying the perfect gift for my children, grandchildren, and my siblings - genealogy test kits! Am I 34% French or are we more Belgian than mom used to tell us????
# ? Dec 6, 2024 11:53 | Profile Message Post History Rap Sheet

Extra Large Marge Jan 21, 2004 Fun Shoe | GM should bring back the Cadillac Eldorado
# ? Dec 6, 2024 12:35 | Profile Post History Rap Sheet

Escape From Noise Jul 27, 2004 | #### big nipples big life posted: that Buscemi minion is so fucking cursed. Kids today just don't understand art.
# ? Dec 6, 2024 12:54 | Profile Message Post History Rap Sheet

Rags to Liches Mar 10, 2008 future skeleton soldier | #### A Fancy Hat posted: did anyone just hear an explosion? I am off Manor Drive heard they were demolishing Bill’s old tire shop today maybe that was what it was??!!
# ? Dec 6, 2024 12:56 | Profile Message Post History Rap Sheet

Peanut Butter Nov 7, 2011 Wee mannie | My posting style Peanut Butter fucked around with this message at 15:53 on Dec 6, 2024
# ? Dec 6, 2024 13:25 | Profile Message Post History Rap Sheet

Haptical Sales Slut Mar 14, 2010 Age 18 to 49 | Show bobs
# ? Dec 6, 2024 13:33 | Profile Message Post History Rap Sheet

redshirt Aug 10, 2007 | It should be illegal to use my name (Karen!) as an insult!
# ? Dec 6, 2024 14:05 | Profile Message Post History Rap Sheet

- 1
- 2
- 3
- 4
- 5

Bookmark this thread
Powered by: vBulletin Version 2.2.9 (SABB-v2.24.12)
Copyright ©2000, 2001, Jelsoft Enterprises Limited.
Copyright ©2024, Jeffrey of YOSPOS
Privacy Policy